@@ -88,6 +88,7 @@ QVector<QDate> DayMatrix::selectedDates() const
     QVector<QDate> selDays;
     if (mSelStart != NO_SELECTION)
     {
+        selDays.reserve(mSelEnd - mSelStart + 1);
         for (int i = mSelStart;  i <= mSelEnd;  ++i)
             selDays.append(mStartDate.addDays(i));
     }
@@ -283,8 +284,9 @@ int DayMatrix::getDayIndex(const QPoint& pt) const
     const int y = pt.y();
     if (x < 0  ||  y < 0  ||  x > width()  ||  y > height())
         return NO_SELECTION;
+    const int xd = static_cast<int>(x / mDaySize.width());
     const int i = 7 * int(y / mDaySize.height())
-                  + int((QApplication::isRightToLeft() ? 6 - x : x) / mDaySize.width());
+                + (QApplication::isRightToLeft() ? 6 - xd : xd);
     if (i < mTodayIndex  ||  i > NUMDAYS-1)
         return NO_SELECTION;
     return i;
@@ -359,7 +361,7 @@ void DayMatrix::mousePressEvent(QMouseEvent* e)
     {
         if (i < mSelStart  ||  i > mSelEnd)
             setMouseSelection(i, i, true);
-        popupMenu();
+        popupMenu(e->globalPos());
     }
     else if (e->button() == Qt::LeftButton)
     {
@@ -374,13 +376,13 @@ void DayMatrix::mousePressEvent(QMouseEvent* e)
     }
 }
 
-void DayMatrix::popupMenu()
+void DayMatrix::popupMenu(const QPoint& pos)
 {
     NewAlarmAction newAction(false, QString(), nullptr);
     QMenu* popup = newAction.menu();
     connect(&newAction, &NewAlarmAction::selected, this, &DayMatrix::newAlarm);
     connect(&newAction, &NewAlarmAction::selectedTemplate, this, &DayMatrix::newAlarmFromTemplate);
-    popup->exec(QCursor::pos());
+    popup->exec(pos);
 }
 
 void DayMatrix::mouseReleaseEvent(QMouseEvent* e)
