@@ -63,10 +63,8 @@ SingleFileResource::SingleFileResource(FileResourceSettings* settings)
     : FileResource(settings)
     , mSaveTimer(new QTimer(this))
 {
-    qCDebug(KALARM_LOG) << "SingleFileResource: Starting" << mSettings->displayName();
-    if (!load())
-        setFailed();
-    else
+    qCDebug(KALARM_LOG) << "SingleFileResource: Starting" << displayName();
+    if (load())
     {
         // Monitor local file changes (but not cache files).
         connect(KDirWatch::self(), &KDirWatch::dirty, this, &SingleFileResource::localFileChanged);
@@ -109,7 +107,7 @@ int SingleFileResource::writableStatus(CalEvent::Type type) const
 */
 bool SingleFileResource::updateStorageFmt()
 {
-    if (failed()  ||  readOnly()  ||  enabledTypes() == CalEvent::EMPTY)
+    if (failed()  ||  readOnly()  ||  enabledTypes() == CalEvent::EMPTY  ||  !mSettings)
         return false;
     if (!mFileStorage)
     {
@@ -124,7 +122,7 @@ bool SingleFileResource::updateStorageFmt()
         return false;
     }
 
-    qCDebug(KALARM_LOG) << "SingleFileResource::updateStorageFormat: Updating storage for" << mSettings->displayName();
+    qCDebug(KALARM_LOG) << "SingleFileResource::updateStorageFormat: Updating storage for" << displayName();
     mCompatibility = KACalendar::Current;
     mVersion = KACalendar::CurrentFormat;
     save(nullptr, true, true);
@@ -167,6 +165,9 @@ bool SingleFileResource::isSaving() const
 */
 int SingleFileResource::doLoad(QHash<QString, KAEvent>& newEvents, bool readThroughCache, QString& errorMessage)
 {
+    if (!mSettings)
+        return -1;
+
     newEvents.clear();
 
     if (mDownloadJob)
@@ -207,7 +208,7 @@ int SingleFileResource::doLoad(QHash<QString, KAEvent>& newEvents, bool readThro
             // The resource's location should never change, so this code should
             // never be reached!
             qCWarning(KALARM_LOG) << "SingleFileResource::load:" << displayId() << "Error? File location changed to" << localFileName;
-            setLoadFailure();
+            setLoadFailure(true, Status::NotConfigured);
             mFileStorage.clear();
             mCalendar.clear();
             mLoadedEvents.clear();
@@ -228,13 +229,26 @@ int SingleFileResource::doLoad(QHash<QString, KAEvent>& newEvents, bool readThro
                 const QString path = mSettings->displayLocation();
                 qCWarning(KALARM_LOG) << "SingleFileResource::load:" << displayId() << "Could not create file" << path;
                 errorMessage = xi18nc("@info", "Could not create calendar file <filename>%1</filename>.", path);
-                mStatus = Status::Broken;
                 mSaveUrl.clear();
-                setLoadFailure();
+                setLoadFailure(false, Status::Broken);
+                return -1;
+            }
+            // Check whether this user can actually write to the newly created file.
+            // This might not tally with the open() permissions, since there are
+            // circumstances on Linux where a file created by a user can be owned by root.
+            QFile fnew(localFileName);
+            if (!fnew.isWritable())
+            {
+                fnew.remove();
+                const QString path = mSettings->displayLocation();
+                qCWarning(KALARM_LOG) << "SingleFileResource::load:" << displayId() << "Could not create writable file" << path;
+                errorMessage = xi18nc("@info", "Could not create calendar file <filename>%1</filename>.", path);
+                mSaveUrl.clear();
+                setLoadFailure(false, Status::Broken);
                 return -1;
             }
             mFileReadOnly = false;
-            mStatus = Status::Ready;
+            setStatus(Status::Ready);
         }
         else
             mFileReadOnly = !QFileInfo(localFileName).isWritable();
@@ -256,7 +270,7 @@ int SingleFileResource::doLoad(QHash<QString, KAEvent>& newEvents, bool readThro
             connect(mDownloadJob, &KJob::result,
                     this, &SingleFileResource::slotDownloadJobResult);
 //            connect(mDownloadJob, SIGNAL(percent(KJob*,ulong)), SLOT(handleProgress(KJob*,ulong)));
-            mStatus = Status::Loading;
+            setStatus(Status::Loading);
             return 0;     // loading initiated
         }
 
@@ -269,8 +283,7 @@ int SingleFileResource::doLoad(QHash<QString, KAEvent>& newEvents, bool readThro
     {
         qCWarning(KALARM_LOG) << "SingleFileResource::load:" << displayId() << "Could not read file" << localFileName;
         // A user error message has been set by readLocalFile().
-        mStatus = Status::Broken;
-        setLoadFailure();
+        setLoadFailure(true, Status::Broken);
         return -1;
     }
 
@@ -278,16 +291,22 @@ int SingleFileResource::doLoad(QHash<QString, KAEvent>& newEvents, bool readThro
         KDirWatch::self()->addFile(settingsLocalFileName);
 
     newEvents = mLoadedEvents;
-    mStatus = Status::Ready;
+    setStatus(Status::Ready);
     return 1;     // success
 }
 
-void SingleFileResource::setLoadFailure()
+/******************************************************************************
+* Called when loading fails.
+* If the resource file doesn't exist or can't be created, the resource is still
+* regarded as loaded.
+*/
+void SingleFileResource::setLoadFailure(bool exists, Status newStatus)
 {
+    setStatus(newStatus);
     mLoadedEvents.clear();
     QHash<QString, KAEvent> events;
     setLoadedEvents(events);
-    setLoaded(false);
+    setLoaded(!exists);
 }
 
 /******************************************************************************
@@ -308,7 +327,7 @@ int SingleFileResource::doSave(bool writeThroughCache, bool force, QString& erro
     if (mSaveUrl.isEmpty())
     {
         qCWarning(KALARM_LOG) << "SingleFileResource::save:" << displayId() << "No file specified";
-        mStatus = Status::Broken;
+        setStatus(Status::Broken);
         return -1;
     }
 
@@ -356,7 +375,7 @@ int SingleFileResource::doSave(bool writeThroughCache, bool force, QString& erro
     {
         qCWarning(KALARM_LOG) << "SingleFileResource::save:" << displayId() << "Error writing to file" << localFileName;
         // A user error message has been set by writeToFile().
-        mStatus = Status::Broken;
+        setStatus(Status::Broken);
         return -1;
     }
 
@@ -370,11 +389,11 @@ int SingleFileResource::doSave(bool writeThroughCache, bool force, QString& erro
         connect(mUploadJob, &KJob::result,
                 this, &SingleFileResource::slotUploadJobResult);
 //        connect(mUploadJob, SIGNAL(percent(KJob*,ulong)), SLOT(handleProgress(KJob*,ulong)));
-        mStatus = Status::Saving;
+        setStatus(Status::Saving);
         return 0;
     }
 
-    mStatus = Status::Ready;
+    setStatus(Status::Ready);
     return 1;
 }
 
@@ -411,11 +430,21 @@ void SingleFileResource::close()
     // QEventLoopLocker should ensure that it continues to completion even if
     // the destructor for this instance is executed.
 
-    if (mSettings->url().isLocalFile())
+    if (mSettings  &&  mSettings->url().isLocalFile())
         KDirWatch::self()->removeFile(mSettings->url().toLocalFile());
     mCalendar.clear();
     mFileStorage.clear();
-    mStatus = Status::Closed;
+    setStatus(Status::Closed);
+}
+
+/******************************************************************************
+* Called when the resource's settings object is about to be destroyed.
+*/
+void SingleFileResource::removeSettings()
+{
+    if (mSettings  &&  mSettings->url().isLocalFile())
+        KDirWatch::self()->removeFile(mSettings->url().toLocalFile());
+    FileResource::removeSettings();
 }
 
 /******************************************************************************
@@ -444,6 +473,9 @@ bool SingleFileResource::doAddEvent(const KAEvent& event)
 */
 bool SingleFileResource::addLoadedEvent(const KCalendarCore::Event::Ptr& kcalEvent)
 {
+    if (!mSettings)
+        return false;
+
     KAEvent event(kcalEvent);
     if (!event.isValid())
     {
@@ -526,6 +558,8 @@ bool SingleFileResource::doDeleteEvent(const KAEvent& event)
 */
 bool SingleFileResource::readLocalFile(const QString& fileName, QString& errorMessage)
 {
+    if (mFileReadOnly  &&  !QFileInfo(fileName).size())
+        return true;
     const QByteArray newHash = calculateHash(fileName);
     if (newHash == mCurrentHash)
         qCDebug(KALARM_LOG) << "SingleFileResource::readLocalFile:" << displayId() << "hash unchanged";
@@ -663,8 +697,11 @@ QByteArray SingleFileResource::calculateHash(const QString& fileName) const
 */
 void SingleFileResource::saveHash(const QByteArray& hash) const
 {
-    mSettings->setHash(hash.toHex());
-    mSettings->save();
+    if (mSettings)
+    {
+        mSettings->setHash(hash.toHex());
+        mSettings->save();
+    }
 }
 
 /******************************************************************************
@@ -673,6 +710,9 @@ void SingleFileResource::saveHash(const QByteArray& hash) const
 */
 void SingleFileResource::localFileChanged(const QString& fileName)
 {
+    if (!mSettings)
+        return;
+
     if (fileName != mSettings->url().toLocalFile())
         return;   // not the calendar file for this resource
 
@@ -696,10 +736,8 @@ void SingleFileResource::slotDownloadJobResult(KJob* job)
     QString errorMessage;
     if (job->error() && job->error() != KIO::ERR_DOES_NOT_EXIST)
     {
-        if (mStatus != Status::Closed)
-            mStatus = Status::Broken;
-        setLoadFailure();
-        const QString path = mSettings->displayLocation();
+        setLoadFailure(false, Status::Broken);
+        const QString path = displayLocation();
         qCWarning(KALARM_LOG) << "SingleFileResource::slotDownloadJobResult:" << displayId() << "Could not load file" << path << job->errorString();
         errorMessage = xi18nc("@info", "Could not load file <filename>%1</filename>. (%2)", path, job->errorString());
         success = false;
@@ -711,13 +749,11 @@ void SingleFileResource::slotDownloadJobResult(KJob* job)
         {
             qCWarning(KALARM_LOG) << "SingleFileResource::slotDownloadJobResult:" << displayId() << "Could not load local file" << localFileName;
             // A user error message has been set by readLocalFile().
-            if (mStatus != Status::Closed)
-                mStatus = Status::Broken;
-            setLoadFailure();
+            setLoadFailure(true, Status::Broken);
             success = false;
         }
-        else if (mStatus != Status::Closed)
-            mStatus = Status::Ready;
+        else
+            setStatus(Status::Ready);
     }
 
     mDownloadJob = nullptr;
@@ -737,15 +773,14 @@ void SingleFileResource::slotUploadJobResult(KJob* job)
     bool success = true;
     if (job->error())
     {
-        if (mStatus != Status::Closed)
-            mStatus = Status::Broken;
-        const QString path = mSettings->displayLocation();
+        setStatus(Status::Broken);
+        const QString path = displayLocation();
         qCWarning(KALARM_LOG) << "SingleFileResource::slotDownloadJobResult:" << displayId() << "Could not save file" << path << job->errorString();
         errorMessage = xi18nc("@info", "Could not save file <filename>%1</filename>. (%2)", path, job->errorString());
         success = false;
     }
-    else if (mStatus != Status::Closed)
-        mStatus = Status::Ready;
+    else
+        setStatus(Status::Ready);
 
     mUploadJob = nullptr;
     auto ref = job->property("QEventLoopLocker").value<QEventLoopLocker*>();
@@ -763,7 +798,7 @@ void SingleFileResource::handleSettingsChange(Changes& changes)
     qCDebug(KALARM_LOG) << "SingleFileResource::handleSettingsChange:" << displayId();
     if (changes & UpdateFormat)
     {
-        if (mSettings->updateFormat())
+        if (mSettings  &&  mSettings->updateFormat())
         {
             // This is a request to update the backend calendar storage format
             // to the current KAlarm format.
